| Title: | Interactive Document for Working with Confusion Matrix |
|---|---|
| Description: | An interactive document on the topic of confusion matrix analysis using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://predanalyticssessions1.shinyapps.io/ConfusionMatrixShiny/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-25 08:49:59 UTC |
| Source: | https://github.com/cran/CMShiny |
CMShiny() loads interactive user interface built using R 'shiny'.
CMShiny()CMShiny()
Start CMShiny
The interactive user interface is to provide an easy way for confusion matrix analysis and downloading relevant plot and dataset.
Nothing
if(interactive()){ library(rmarkdown) CMShiny() }if(interactive()){ library(rmarkdown) CMShiny() }